@@ -1,19 +1,21 @@
 from redis.exceptions import ConnectionError
 from threading import Thread
-from queue import Queue, Empty
-import typing
+try:
+    import queue
+except ImportError:
+    import Queue as queue
 import redis
 import time
 import json
 
 
-class IotRedisBasic:
+class IotRedisBasic(object):
     """Basic redis variable to set and retrieve data
 
     Base class for Redis variable"""
 
     def __init__(self):
-        super().__init__()
+        super(IotRedisBasic, self).__init__()
         self.rdb = redis.Redis(
             host='localhost',
             port=6379,
@@ -52,14 +54,17 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
     to a custom function.
     """
 
-    def __init__(self, *channels_to_consume, func_handler=None):
+    def __init__(self, *channels_to_consume, **kwargs):
         # type: (*str, any) -> None
 
-        super().__init__()
+        super(IotRedisSubscriber, self).__init__()
         self.daemon = True
-        self.data_list = Queue()
+        self.data_list = queue.Queue()
         self.init_channels = list(channels_to_consume)
-        self.func_handler = func_handler
+        if 'func_handler' in kwargs:
+            self.func_handler = kwargs.pop('func_handler')
+        else:
+            self.func_handler = None
         # Create pubsub instance for subscribe
         self.pubsub = self.rdb.pubsub(ignore_subscribe_messages=True)
 
@@ -110,7 +115,7 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
             try:  # Suscribe to every channel
                 self.pubsub.subscribe(*channels_to_consume)
             except ConnectionError as err:
-                print(f"Error trying to connect to server: {err}")
+                print("Error trying to connect to server:", err)
                 time.sleep(1)
             else:  # If no error
                 break
@@ -121,7 +126,7 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
         try:
             self.pubsub.unsubscribe(channels_to_unsubscribe)
         except ConnectionError as err:
-            print(f"Error trying to unsusbscribe to server: {err}")
+            print("Error trying to unsusbscribe to server:", err)
             time.sleep(1)
 
     def data_available(self):
@@ -134,13 +139,13 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
 
         try:
             return self.data_list.get_nowait()
-        except Empty as _:
+        except queue.Empty as _:
             return
 
 
 class IotRedisPublisher(IotRedisBasic):
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+        super(IotRedisPublisher, self).__init__(*args, **kwargs)
 
     def publish(self, channel, data):
         # type: (str, dict) -> None
@@ -155,11 +160,11 @@ class IotRedisPublisher(IotRedisBasic):
 
 class IotRedisPubSub(IotRedisPublisher, IotRedisSubscriber):
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+        super(IotRedisPubSub, self).__init__(*args, **kwargs)
 
 
 if __name__ == '__main__':
-    pubsub = IotRedisPubSub("hola", "opcua", func_handler=print)
+    pubsub = IotRedisPubSub("hola", "opcua")
     print(pubsub.channels)
     sample_consumer = IotRedisSubscriber('prueba1', 'prueba2')
     sample_consumer.start()
